@@ -1,7 +1,7 @@
 package Regexp::Pattern::Example;
 
-our $DATE = '2016-09-13'; # DATE
-our $VERSION = '0.1.1'; # VERSION
+our $DATE = '2016-09-14'; # DATE
+our $VERSION = '0.1.2'; # VERSION
 
 # BEGIN_BLOCK: def
 
@@ -30,7 +30,7 @@ _
 _
         gen => sub {
             my %args = @_;
-            my $variant = $args{variant} // 'A';
+            my $variant = $args{variant} || 'A';
             if ($variant eq 'A') {
                 return qr/\d{3}-\d{3}/;
             } else { # B
@@ -65,7 +65,7 @@ Regexp::Pattern::Example - An example Regexp::Pattern::* module
 
 =head1 VERSION
 
-This document describes version 0.1.1 of Regexp::Pattern::Example (from Perl distribution Regexp-Pattern), released on 2016-09-13.
+This document describes version 0.1.2 of Regexp::Pattern::Example (from Perl distribution Regexp-Pattern), released on 2016-09-14.
 
 =head1 SYNOPSIS
 
